@@ -320,10 +320,11 @@ class PySob:
                     self.__dict__[attr] = rec[inx]
             self._is_new = False
             if __references:
-                self.load_references(__references,
-                                     db_engine=db_engine,
-                                     db_conn=db_conn,
-                                     errors=errors)
+                PySob.__load_references(__references,
+                                        objs=[self],
+                                        db_engine=db_engine,
+                                        db_conn=db_conn,
+                                        errors=errors)
             result = not errors
 
         return result
@@ -367,21 +368,9 @@ class PySob:
 
         return result
 
-    def load_reference(self,
-                       __reference: type,
-                       /,
-                       db_engine: DbEngine = None,
-                       db_conn: Any = None,
-                       errors: list[str] = None) -> None:
-
-        self.load_references([__reference],
-                             db_engine=db_engine,
-                             db_conn=db_conn,
-                             errors=errors)
-
     # noinspection PyUnusedLocal
     def load_references(self,
-                        __references: list[type],
+                        __references: type[Sob] | type[list[Sob]] | list[type[Sob] | type[list[Sob]]],
                         /,
                         db_engine: DbEngine = None,
                         db_conn: Any = None,
@@ -395,21 +384,9 @@ class PySob:
         if self._logger:
             self._logger.error(msg=msg)
 
-    def invalidate_reference(self,
-                             __reference: type,
-                             /,
-                             db_engine: DbEngine = None,
-                             db_conn: Any = None,
-                             errors: list[str] = None) -> None:
-
-        self.invalidate_references([__reference],
-                                   db_engine=db_engine,
-                                   db_conn=db_conn,
-                                   errors=errors)
-
     # noinspection PyUnusedLocal
     def invalidate_references(self,
-                              __references: list[type],
+                              __references: type[Sob] | type[list[Sob]] | list[type[Sob] | type[list[Sob]]],
                               /,
                               db_engine: DbEngine = None,
                               db_conn: Any = None,
@@ -622,30 +599,11 @@ class PySob:
                     objs.append(sob)
 
                 if __references:
-                    if SOB_MAX_THREADS > 1:
-                        task_futures: list[Future] = []
-                        with ThreadPoolExecutor(max_workers=SOB_MAX_THREADS) as executor:
-                            for obj in objs:
-                                # HAZARD: must not use 'db_conn' concurrently
-                                future: Future = executor.submit(obj.load_references,
-                                                                 __references,
-                                                                 # db_conn=db_conn,
-                                                                 db_engine=db_engine,
-                                                                 errors=errors)
-                                task_futures.append(future)
-
-                        # wait for all task futures to complete, then shutdown down the executor
-                        futures.wait(fs=task_futures)
-                        executor.shutdown(wait=False)
-
-                    else:
-                        for obj in objs:
-                            obj.load_references(__references,
-                                                db_engine=db_engine,
-                                                db_conn=db_conn,
-                                                errors=errors)
-                            if errors:
-                                break
+                    PySob.__load_references(__references,
+                                            objs=objs,
+                                            db_engine=db_engine,
+                                            db_conn=db_conn,
+                                            errors=errors)
                 if not errors:
                     result = objs
 
@@ -655,13 +613,13 @@ class PySob:
         return result
 
     @staticmethod
-    def include(insert_data: dict[str, Any] = None,
-                return_cols: dict[str, Any] = None,
-                db_engine: DbEngine = None,
-                db_conn: Any = None,
-                committable: bool = None,
-                errors: list[str] = None,
-                logger: Logger = None) -> tuple | int | None:
+    def store(insert_data: dict[str, Any] = None,
+              return_cols: dict[str, Any] = None,
+              db_engine: DbEngine = None,
+              db_conn: Any = None,
+              committable: bool = None,
+              errors: list[str] = None,
+              logger: Logger = None) -> tuple | int | None:
 
         # initialize the return variable
         result: tuple | int | None = None
@@ -790,3 +748,40 @@ class PySob:
                 errors.append(msg)
 
         return result
+
+    @staticmethod
+    def __load_references(__references: list[type],
+                          /,
+                          objs: list[Sob],
+                          db_engine: DbEngine = None,
+                          db_conn: Any = None,
+                          errors: list[str] = None) -> None:
+
+        if SOB_MAX_THREADS > 1 and \
+                (len(objs) > 1 or len(__references) > 1):
+            task_futures: list[Future] = []
+            with ThreadPoolExecutor(max_workers=SOB_MAX_THREADS) as executor:
+                for obj in objs:
+                    for __reference in __references:
+                        # must not multiplex 'db_conn'
+                        future: Future = executor.submit(obj.load_references,
+                                                         [__reference],
+                                                         db_engine=db_engine,
+                                                         errors=errors)
+                        if errors:
+                            break
+                        task_futures.append(future)
+                    if errors:
+                        break
+
+            # wait for all task futures to complete, then shutdown down the executor
+            futures.wait(fs=task_futures)
+            executor.shutdown(wait=False)
+        else:
+            for obj in objs:
+                obj.load_references(__references,
+                                    db_engine=db_engine,
+                                    db_conn=db_conn,
+                                    errors=errors)
+                if errors:
+                    break
